==> change_labels-1.3.1.tar.gz: change_labels/src/EventSubscriber/ChangeNumberFieldSubscriber.php <==
<?php

namespace Drupal\change_labels\EventSubscriber;

use Drupal\Core\Field\Plugin\Field\FieldWidget\NumberWidget;
use Drupal\Core\Render\Element;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\field_event_dispatcher\Event\Field\FieldWidgetThirdPartySettingsFormEvent;
use Drupal\field_event_dispatcher\Event\Field\WidgetCompleteFormAlterEvent;
use Drupal\field_event_dispatcher\FieldHookEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Change labels event subscriber.
 */
class ChangeNumberFieldSubscriber implements EventSubscriberInterface {

  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      FieldHookEvents::FIELD_WIDGET_THIRD_PARTY_SETTINGS_FORM => ['addSettings'],
      FieldHookEvents::WIDGET_COMPLETE_FORM_ALTER => ['alterForm'],
    ];
  }

  /**
   * Event handler for the third party settings of a widget.
   *
   * @param \Drupal\field_event_dispatcher\Event\Field\FieldWidgetThirdPartySettingsFormEvent $event
   *   Triggering event.
   */
  public function addSettings(FieldWidgetThirdPartySettingsFormEvent $event) {
    if (!is_a($event->getPlugin(), NumberWidget::class)) {
      return;
    }
    $element = [];
    $element['number_size'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Number field size'),
      '#default_value' => $event->getPlugin()->getThirdPartySetting('change_labels', 'number_size'),
    ];
    $event->addElements('change_labels', $element);
  }

  /**
   * Event handler for altering a widget.
   *
   * @param \Drupal\field_event_dispatcher\Event\Field\WidgetCompleteFormAlterEvent $event
   *   Triggering event.
   */
  public function alterForm(WidgetCompleteFormAlterEvent $event) {
    $setting = $event->getContext()['widget']->getThirdPartySetting('change_labels', 'number_size');
    if ($setting) {
      $elements = &$event->getElements();
      foreach (Element::children($elements) as $child) {
        $elements[$child]['value']['#size'] = $setting;
      }
    }
  }

}

==> change_labels-1.3.5.tar.gz: change_labels/src/EventSubscriber/ChangeNumberFieldSubscriber.php <==
<?php

namespace Drupal\change_labels\EventSubscriber;

use Drupal\Core\Field\Plugin\Field\FieldWidget\NumberWidget;
use Drupal\Core\Render\Element;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\field_event_dispatcher\Event\Field\FieldWidgetThirdPartySettingsFormEvent;
use Drupal\field_event_dispatcher\Event\Field\WidgetCompleteFormAlterEvent;
use Drupal\field_event_dispatcher\FieldHookEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Change labels event subscriber.
 */
class ChangeNumberFieldSubscriber implements EventSubscriberInterface {

  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    return [
      FieldHookEvents::FIELD_WIDGET_THIRD_PARTY_SETTINGS_FORM => ['addSettings'],
      FieldHookEvents::WIDGET_COMPLETE_FORM_ALTER => ['alterForm'],
    ];
  }

  /**
   * Event handler for the third party settings of a widget.
   *
   * @param \Drupal\field_event_dispatcher\Event\Field\FieldWidgetThirdPartySettingsFormEvent $event
   *   Triggering event.
   */
  public function addSettings(FieldWidgetThirdPartySettingsFormEvent $event) {
    if (!is_a($event->getPlugin(), NumberWidget::class)) {
      return;
    }
    $element = [];
    $element['number_size'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Number field size'),
      '#default_value' => $event->getPlugin()->getThirdPartySetting('change_labels', 'number_size'),
    ];
    $event->addElements('change_labels', $element);
  }

  /**
   * Event handler for altering a widget.
   *
   * @param \Drupal\field_event_dispatcher\Event\Field\WidgetCompleteFormAlterEvent $event
   *   Triggering event.
   */
  public function alterForm(WidgetCompleteFormAlterEvent $event) {
    $setting = $event->getContext()['widget']->getThirdPartySetting('change_labels', 'number_size');
    if ($setting) {
      $elements = &$event->getElements();
      foreach (Element::children($elements) as $child) {
        $elements[$child]['value']['#size'] = $setting;
      }
    }
  }

}
